@@ -1,3 +1,3 @@
 # needed for site_reference_configs.autodiscover test
 
-raise TypeError("the earth is not round")
+raise TypeError("the earth is not round?")
