@@ -1,13 +1,15 @@
 from dateutil.relativedelta import relativedelta
 from django.contrib.sites.models import Site
 from django.test import TestCase as BaseTestCase
+from edc_appointment.constants import INCOMPLETE_APPT
 from edc_appointment.models import Appointment
 from edc_facility import import_holidays
 from edc_utils import get_utcnow
 from edc_visit_schedule import site_visit_schedules
 from edc_visit_tracking.constants import SCHEDULED
+from edc_visit_tracking.models import SubjectVisit
 
-from reference_app.models import SubjectConsent, SubjectVisit
+from reference_app.models import SubjectConsent
 
 
 class TestCase(BaseTestCase):
@@ -43,3 +45,5 @@ class TestCase(BaseTestCase):
                     schedule_name=appointment.schedule_name,
                 )
             )
+            appointment.appt_status = INCOMPLETE_APPT
+            appointment.save()
