@@ -41,7 +41,7 @@ class TestLongitudinal(TestCase):
     def test_longitudinal_refsets(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -53,7 +53,7 @@ class TestLongitudinal(TestCase):
     def test_longitudinal_refset_uses_subject_visit_report_datetime(self):
         longitudinal_refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -72,7 +72,7 @@ class TestLongitudinal(TestCase):
     def test_no_refsets(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -82,7 +82,7 @@ class TestLongitudinal(TestCase):
     def test_ordering(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         ).order_by("-report_datetime")
@@ -111,7 +111,7 @@ class TestLongitudinal(TestCase):
             InvalidOrdering,
             LongitudinalRefsets(
                 subject_identifier=self.subject_identifier,
-                visit_model="reference_app.subjectvisit",
+                visit_model="edc_visit_tracking.subjectvisit",
                 name="reference_app.crfone",
                 reference_model_cls=Reference,
             ).order_by,
@@ -121,7 +121,7 @@ class TestLongitudinal(TestCase):
     def test_get(self):
         refset = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -134,7 +134,7 @@ class TestLongitudinal(TestCase):
     def test_get2(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -150,7 +150,7 @@ class TestLongitudinal(TestCase):
     def test_get_last(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -164,7 +164,7 @@ class TestLongitudinal(TestCase):
     def test_repr(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls=Reference,
         )
@@ -175,7 +175,7 @@ class TestLongitudinal(TestCase):
     def test_with_model_name(self):
         refsets = LongitudinalRefsets(
             subject_identifier=self.subject_identifier,
-            visit_model="reference_app.subjectvisit",
+            visit_model="edc_visit_tracking.subjectvisit",
             name="reference_app.crfone",
             reference_model_cls="edc_reference.reference",
         )
