@@ -1,14 +1,13 @@
 from datetime import date
-from decimal import Decimal
 
 from dateutil.relativedelta import relativedelta
 from django.contrib.sites.models import Site
 from django.core.exceptions import ObjectDoesNotExist
-from django.test import TestCase
-from edc_appointment.models import Appointment
 from edc_lab.models.panel import Panel
+from edc_lab_panel.constants import CD4, FBC, VL
 from edc_utils import get_utcnow
-from edc_visit_tracking.constants import SCHEDULED
+from edc_visit_schedule import site_visit_schedules
+from edc_visit_tracking.models import SubjectVisit
 
 from edc_reference.models import Reference, ReferenceFieldDatatypeNotFound
 from edc_reference.reference import (
@@ -28,48 +27,29 @@ from edc_reference.site_reference import site_reference_configs
 from reference_app.models import (
     CrfOne,
     CrfWithUnknownDatatype,
-    SubjectConsent,
     SubjectRequisition,
-    SubjectVisit,
     TestModel,
 )
 from reference_app.reference_model_configs import register_configs
 from reference_app.visit_schedules import visit_schedule
 
+from .test_case import TestCase
+
 
 class TestReferenceModel(TestCase):
     def setUp(self):
-        self.panel_cd4 = Panel.objects.create(name="cd4")
-        self.panel_vl = Panel.objects.create(name="vl")
-        self.panel_wb = Panel.objects.create(name="wb")
-        self.subject_identifier = "123456789"
+        super().setUp()
 
-        dte = get_utcnow()
-
-        SubjectConsent.objects.create(
-            consent_datetime=dte,
-            subject_identifier=self.subject_identifier,
-            identity="012345678",
-            confirm_identity="012345678",
-            site=Site.objects.get_current(),
-        )
-
-        appointment = Appointment.objects.create(
-            subject_identifier=self.subject_identifier,
-            appt_datetime=dte,
-            timepoint_datetime=dte,
-            visit_schedule_name=visit_schedule.name,
-            schedule_name="schedule",
-            visit_code="1000",
-            timepoint=Decimal("1.0"),
-            site=Site.objects.get_current(),
-        )
-
-        self.subject_visit = SubjectVisit.objects.create(
-            appointment=appointment,
-            reason=SCHEDULED,
-            site=Site.objects.get_current(),
+        self.panel_cd4 = Panel.objects.get(name=CD4)
+        self.panel_vl = Panel.objects.get(name=VL)
+        self.panel_fbc = Panel.objects.get(name=FBC)
+        self.site = Site.objects.get_current()
+        site_visit_schedules._registry = {}
+        site_visit_schedules.register(visit_schedule)
+        site_reference_configs.register_from_visit_schedule(
+            visit_models={"edc_appointment.appointment": "edc_visit_tracking.subjectvisit"}
         )
+        self.subject_visit = SubjectVisit.objects.get(visit_code="1000")
 
     def reset_site_reference_configs(self):
         site_reference_configs.registry = {}
@@ -77,7 +57,7 @@ class TestReferenceModel(TestCase):
         site_reference_configs.registered_from_visit_schedules = False
 
         subjectvisit_reference = ReferenceModelConfig(
-            name="reference_app.subjectvisit", fields=["report_datetime", "visit_code"]
+            name="edc_visist_tracking.subjectvisit", fields=["report_datetime", "visit_code"]
         )
 
         self.testmodel_reference = ReferenceModelConfig(
@@ -422,7 +402,7 @@ class TestReferenceModel(TestCase):
         reference = ReferenceGetter(
             name="reference_app.crfone",
             field_name="field_int",
-            visit_obj=crf_one.related_visit,
+            related_visit=crf_one.related_visit,
         )
         self.assertEqual(reference.field_int, integer)
 
@@ -443,6 +423,7 @@ class TestReferenceModel(TestCase):
             visit_code=crf_one.related_visit.visit_code,
             visit_code_sequence=crf_one.related_visit.visit_code_sequence,
             timepoint=crf_one.related_visit.timepoint,
+            site=crf_one.site,
         )
         reference = ReferenceGetter(**opts)
         self.assertEqual(reference.field_int, integer)
@@ -463,12 +444,15 @@ class TestReferenceModel(TestCase):
             schedule_name=crf_one.related_visit.schedule_name,
             visit_code=crf_one.related_visit.visit_code,
             timepoint=crf_one.related_visit.timepoint,
+            site=crf_one.site,
         )
+        self.assertRaises(ReferenceGetterError, ReferenceGetter, **opts)
+        opts.update(visit_code_sequence=0)
         reference = ReferenceGetter(**opts)
         self.assertEqual(reference.field_int, integer)
 
-    def test_reference_getter_raises(self):
-        """Assert raises if reference instance does not exist
+    def test_reference_getter_raises_if_create_is_false(self):
+        """Assert raises if Reference model instance does not exist
         and not create.
         """
         opts = dict(
@@ -476,6 +460,13 @@ class TestReferenceModel(TestCase):
             field_name="field_int",
             subject_identifier=self.subject_identifier,
             report_datetime=self.subject_visit.report_datetime,
+            visit_schedule_name=self.subject_visit.visit_schedule_name,
+            schedule_name=self.subject_visit.schedule_name,
+            visit_code=self.subject_visit.visit_code,
+            visit_code_sequence=self.subject_visit.visit_code_sequence,
+            timepoint=self.subject_visit.timepoint,
+            site=self.subject_visit.site,
+            create=False,
         )
         self.assertRaises(ReferenceObjectDoesNotExist, ReferenceGetter, **opts)
 
@@ -493,16 +484,12 @@ class TestReferenceModel(TestCase):
         integer = 100
         crf_one = CrfOne.objects.create(subject_visit=self.subject_visit, field_int=integer)
         self.assertRaises(
-            ReferenceObjectDoesNotExist,
+            ReferenceGetterError,
             ReferenceGetter,
             name="reference_app.crfone",
             field_name="blah",
             model_obj=crf_one,
         )
-        try:
-            ReferenceGetter(field_name="blah", name="reference_app.crfone", model_obj=crf_one)
-        except ReferenceObjectDoesNotExist:
-            pass
 
     def test_reference_getter_object_doesnotexist(self):
         crf_one_obj = CrfOne.objects.create(
@@ -513,11 +500,11 @@ class TestReferenceModel(TestCase):
             field_datetime=get_utcnow(),
         )
         self.assertRaises(
-            ReferenceObjectDoesNotExist,
+            ReferenceGetterError,
             ReferenceGetter,
             field_name="blah",
             model_obj=crf_one_obj,
-            visit_obj=self.subject_visit,
+            related_visit=self.subject_visit,
             create=False,
         )
 
@@ -574,7 +561,7 @@ class TestReferenceModel(TestCase):
             subject_visit=self.subject_visit, panel=self.panel_cd4
         )
         obj = Reference.objects.get_requisition_for_visit(
-            "reference_app.subjectrequisition.cd4", self.subject_visit
+            f"reference_app.subjectrequisition.{CD4}", self.subject_visit
         )
         self.assertEqual(obj.value, self.panel_cd4.id)
         obj = Reference.objects.get_requisition_for_visit(
@@ -590,11 +577,11 @@ class TestReferenceModel(TestCase):
             subject_visit=self.subject_visit, panel=self.panel_vl
         )
         obj = Reference.objects.get_requisition_for_visit(
-            "reference_app.subjectrequisition.vl", self.subject_visit
+            f"reference_app.subjectrequisition.{VL}", self.subject_visit
         )
         self.assertEqual(obj.value, self.panel_vl.id)
         obj = Reference.objects.get_requisition_for_visit(
-            "reference_app.subjectrequisition.cd4", self.subject_visit
+            f"reference_app.subjectrequisition.{CD4}", self.subject_visit
         )
         self.assertEqual(obj.value, self.panel_cd4.id)
         obj = Reference.objects.get_requisition_for_visit(
@@ -610,10 +597,10 @@ class TestReferenceModel(TestCase):
             subject_visit=self.subject_visit, panel=self.panel_cd4
         )
         SubjectRequisition.objects.create(
-            subject_visit=self.subject_visit, panel=self.panel_wb
+            subject_visit=self.subject_visit, panel=self.panel_fbc
         )
 
-        for panel in [self.panel_cd4, self.panel_vl, self.panel_wb]:
+        for panel in [self.panel_cd4, self.panel_vl, self.panel_fbc]:
             with self.subTest(panel=panel):
                 Reference.objects.get(
                     model=f"reference_app.subjectrequisition.{panel.name}",
