@@ -1,11 +1,25 @@
 from dateutil.relativedelta import relativedelta
+from edc_lab_panel.panels import cd4_panel, fbc_panel, vl_panel
+from edc_visit_schedule import Requisition
 from edc_visit_schedule.schedule import Schedule
 from edc_visit_schedule.site_visit_schedules import site_visit_schedules
 from edc_visit_schedule.visit import Crf, FormsCollection, Visit
 from edc_visit_schedule.visit_schedule import VisitSchedule
 
-crfs = FormsCollection(Crf(show_order=1, model="reference_app.crfone", required=True))
+from .lab_profiles import panel_one, panel_two
 
+crfs = FormsCollection(
+    Crf(show_order=10, model="reference_app.crfone", required=True),
+    Crf(show_order=20, model="reference_app.testmodel", required=True),
+)
+
+requisitions = FormsCollection(
+    Requisition(show_order=10, panel=cd4_panel, required=True, additional=False),
+    Requisition(show_order=20, panel=panel_one, required=True, additional=False),
+    Requisition(show_order=30, panel=panel_two, required=True, additional=False),
+    Requisition(show_order=40, panel=fbc_panel, required=True, additional=False),
+    Requisition(show_order=50, panel=vl_panel, required=True, additional=False),
+)
 
 visit0 = Visit(
     code="1000",
@@ -15,6 +29,7 @@ visit0 = Visit(
     rlower=relativedelta(days=0),
     rupper=relativedelta(days=6),
     crfs=crfs,
+    requisitions=requisitions,
     facility_name="7-day-clinic",
 )
 
@@ -26,6 +41,7 @@ visit1 = Visit(
     rlower=relativedelta(days=6),
     rupper=relativedelta(days=6),
     crfs=crfs,
+    requisitions=requisitions,
     facility_name="7-day-clinic",
 )
 
@@ -37,6 +53,7 @@ visit2 = Visit(
     rlower=relativedelta(days=6),
     rupper=relativedelta(days=6),
     crfs=crfs,
+    requisitions=requisitions,
     facility_name="7-day-clinic",
 )
 
