@@ -17,7 +17,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
     BASE_DIR=base_dir,
     APP_NAME=app_name,
     ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
-    SUBJECT_VISIT_MODEL="edc_reference.subjectvisit",
+    SUBJECT_VISIT_MODEL="edc_visit_tracking.subjectvisit",
     INSTALLED_APPS=[
         "django.contrib.admin",
         "django.contrib.auth",
@@ -28,11 +28,17 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "django.contrib.sites",
         "django_crypto_fields.apps.AppConfig",
         "django_revision.apps.AppConfig",
+        "edc_action_item.apps.AppConfig",
         "edc_appointment.apps.AppConfig",
         "edc_consent.apps.AppConfig",
         "edc_crf.apps.AppConfig",
         "edc_device.apps.AppConfig",
+        "edc_identifier.apps.AppConfig",
+        "edc_facility.apps.AppConfig",
+        "edc_list_data.apps.AppConfig",
         "edc_lab.apps.AppConfig",
+        "edc_metadata.apps.AppConfig",
+        "edc_notification.apps.AppConfig",
         "edc_sites.apps.AppConfig",
         "edc_protocol.apps.AppConfig",
         "edc_visit_tracking.apps.AppConfig",
@@ -41,8 +47,6 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_reference.apps.AppConfig",
         "edc_registration.apps.AppConfig",
         "edc_timepoint.apps.AppConfig",
-        "reference_app.apps.EdcFacilityAppConfig",
-        "reference_app.apps.EdcMetadataAppConfig",
         "reference_app.apps.AppConfig",
     ],
     add_dashboard_middleware=True,
